Document (document) — Orange Canvas Core 0.0.9 documentation

# Orange Canvas Core 0.0.9 documentation

## Document (document)

# Document (`document`)

## Document

The `document` package contains classes for visual interactive editing of a `Scheme` instance.

The `SchemeEditWidget` is the main widget used for editing. It uses classes defined in `canvas` to display the scheme. It also supports undo/redo functionality.

- Scheme Editor (`schemeedit`)
  - Scheme Editor Widget
- Quick Menu (`quickmenu`)
  - Quick Menu